@@ -30,6 +30,7 @@
 #include <QtMultimedia/qmediaplayer.h>
 #include <QtMultimedia/qmediarecorder.h>
 #include <QtMultimedia/qmediatimerange.h>
+#include <QtMultimedia/qplaybackoptions.h>
 #include <QtMultimedia/qscreencapture.h>
 #include <QtMultimedia/qsoundeffect.h>
 #include <QtMultimedia/qtvideo.h>
@@ -104,45 +105,48 @@ enum [[deprecated]] : int {
     SBK_QMEDIAFORMAT_IDX                                     = 82,
     SBK_QMEDIAMETADATA_KEY_IDX                               = 96,
     SBK_QMEDIAMETADATA_IDX                                   = 94,
-    SBK_QMEDIAPLAYER_PLAYBACKSTATE_IDX                       = 106,
+    SBK_QMEDIAPLAYER_PLAYBACKSTATE_IDX                       = 108,
     SBK_QMEDIAPLAYER_MEDIASTATUS_IDX                         = 104,
     SBK_QMEDIAPLAYER_ERROR_IDX                               = 100,
     SBK_QMEDIAPLAYER_LOOPS_IDX                               = 102,
+    SBK_QMEDIAPLAYER_PITCHCOMPENSATIONAVAILABILITY_IDX       = 106,
     SBK_QMEDIAPLAYER_IDX                                     = 98,
-    SBK_QMEDIARECORDER_QUALITY_IDX                           = 114,
-    SBK_QMEDIARECORDER_ENCODINGMODE_IDX                      = 110,
-    SBK_QMEDIARECORDER_RECORDERSTATE_IDX                     = 116,
-    SBK_QMEDIARECORDER_ERROR_IDX                             = 112,
-    SBK_QMEDIARECORDER_IDX                                   = 108,
-    SBK_QMEDIATIMERANGE_IDX                                  = 118,
-    SBK_QMEDIATIMERANGE_INTERVAL_IDX                         = 120,
-    SBK_QSCREENCAPTURE_ERROR_IDX                             = 124,
-    SBK_QSCREENCAPTURE_IDX                                   = 122,
-    SBK_QSOUNDEFFECT_LOOP_IDX                                = 128,
-    SBK_QSOUNDEFFECT_STATUS_IDX                              = 130,
-    SBK_QSOUNDEFFECT_IDX                                     = 126,
-    SBK_QVIDEOFRAME_HANDLETYPE_IDX                           = 134,
-    SBK_QVIDEOFRAME_MAPMODE_IDX                              = 136,
-    SBK_QVIDEOFRAME_ROTATIONANGLE_IDX                        = 142,
-    SBK_QVIDEOFRAME_IDX                                      = 132,
-    SBK_QVIDEOFRAME_PAINTOPTIONS_PAINTFLAG_IDX               = 140,
+    SBK_QMEDIARECORDER_QUALITY_IDX                           = 116,
+    SBK_QMEDIARECORDER_ENCODINGMODE_IDX                      = 112,
+    SBK_QMEDIARECORDER_RECORDERSTATE_IDX                     = 118,
+    SBK_QMEDIARECORDER_ERROR_IDX                             = 114,
+    SBK_QMEDIARECORDER_IDX                                   = 110,
+    SBK_QMEDIATIMERANGE_IDX                                  = 120,
+    SBK_QMEDIATIMERANGE_INTERVAL_IDX                         = 122,
+    SBK_QPLAYBACKOPTIONS_PLAYBACKINTENT_IDX                  = 126,
+    SBK_QPLAYBACKOPTIONS_IDX                                 = 124,
+    SBK_QSCREENCAPTURE_ERROR_IDX                             = 130,
+    SBK_QSCREENCAPTURE_IDX                                   = 128,
+    SBK_QSOUNDEFFECT_LOOP_IDX                                = 134,
+    SBK_QSOUNDEFFECT_STATUS_IDX                              = 136,
+    SBK_QSOUNDEFFECT_IDX                                     = 132,
+    SBK_QVIDEOFRAME_HANDLETYPE_IDX                           = 140,
+    SBK_QVIDEOFRAME_MAPMODE_IDX                              = 142,
+    SBK_QVIDEOFRAME_ROTATIONANGLE_IDX                        = 148,
+    SBK_QVIDEOFRAME_IDX                                      = 138,
+    SBK_QVIDEOFRAME_PAINTOPTIONS_PAINTFLAG_IDX               = 146,
     SBK_QFLAGS_QVIDEOFRAME_PAINTOPTIONS_PAINTFLAG_IDX        = 68,
-    SBK_QVIDEOFRAME_PAINTOPTIONS_IDX                         = 138,
-    SBK_QVIDEOFRAMEFORMAT_PIXELFORMAT_IDX                    = 154,
-    SBK_QVIDEOFRAMEFORMAT_DIRECTION_IDX                      = 152,
-    SBK_QVIDEOFRAMEFORMAT_YCBCRCOLORSPACE_IDX                = 156,
-    SBK_QVIDEOFRAMEFORMAT_COLORSPACE_IDX                     = 148,
-    SBK_QVIDEOFRAMEFORMAT_COLORTRANSFER_IDX                  = 150,
-    SBK_QVIDEOFRAMEFORMAT_COLORRANGE_IDX                     = 146,
-    SBK_QVIDEOFRAMEFORMAT_IDX                                = 144,
-    SBK_QVIDEOFRAMEINPUT_IDX                                 = 158,
-    SBK_QVIDEOSINK_IDX                                       = 160,
-    SBK_QWAVEDECODER_IDX                                     = 162,
-    SBK_QWINDOWCAPTURE_ERROR_IDX                             = 166,
-    SBK_QWINDOWCAPTURE_IDX                                   = 164,
-    SBK_QTVIDEO_ROTATION_IDX                                 = 170,
-    SBK_QTMULTIMEDIAQTVIDEO_IDX                              = 168,
-    SBK_QTMULTIMEDIA_IDX_COUNT                               = 172,
+    SBK_QVIDEOFRAME_PAINTOPTIONS_IDX                         = 144,
+    SBK_QVIDEOFRAMEFORMAT_PIXELFORMAT_IDX                    = 160,
+    SBK_QVIDEOFRAMEFORMAT_DIRECTION_IDX                      = 158,
+    SBK_QVIDEOFRAMEFORMAT_YCBCRCOLORSPACE_IDX                = 162,
+    SBK_QVIDEOFRAMEFORMAT_COLORSPACE_IDX                     = 154,
+    SBK_QVIDEOFRAMEFORMAT_COLORTRANSFER_IDX                  = 156,
+    SBK_QVIDEOFRAMEFORMAT_COLORRANGE_IDX                     = 152,
+    SBK_QVIDEOFRAMEFORMAT_IDX                                = 150,
+    SBK_QVIDEOFRAMEINPUT_IDX                                 = 164,
+    SBK_QVIDEOSINK_IDX                                       = 166,
+    SBK_QWAVEDECODER_IDX                                     = 168,
+    SBK_QWINDOWCAPTURE_ERROR_IDX                             = 172,
+    SBK_QWINDOWCAPTURE_IDX                                   = 170,
+    SBK_QTVIDEO_ROTATION_IDX                                 = 176,
+    SBK_QTMULTIMEDIAQTVIDEO_IDX                              = 174,
+    SBK_QTMULTIMEDIA_IDX_COUNT                               = 178,
 };
 
 // Type indices
@@ -195,45 +199,48 @@ enum : int {
     SBK_QMediaFormat_IDX                                     = 41,
     SBK_QMediaMetaData_Key_IDX                               = 48,
     SBK_QMediaMetaData_IDX                                   = 47,
-    SBK_QMediaPlayer_PlaybackState_IDX                       = 53,
+    SBK_QMediaPlayer_PlaybackState_IDX                       = 54,
     SBK_QMediaPlayer_MediaStatus_IDX                         = 52,
     SBK_QMediaPlayer_Error_IDX                               = 50,
     SBK_QMediaPlayer_Loops_IDX                               = 51,
+    SBK_QMediaPlayer_PitchCompensationAvailability_IDX       = 53,
     SBK_QMediaPlayer_IDX                                     = 49,
-    SBK_QMediaRecorder_Quality_IDX                           = 57,
-    SBK_QMediaRecorder_EncodingMode_IDX                      = 55,
-    SBK_QMediaRecorder_RecorderState_IDX                     = 58,
-    SBK_QMediaRecorder_Error_IDX                             = 56,
-    SBK_QMediaRecorder_IDX                                   = 54,
-    SBK_QMediaTimeRange_IDX                                  = 59,
-    SBK_QMediaTimeRange_Interval_IDX                         = 60,
-    SBK_QScreenCapture_Error_IDX                             = 62,
-    SBK_QScreenCapture_IDX                                   = 61,
-    SBK_QSoundEffect_Loop_IDX                                = 64,
-    SBK_QSoundEffect_Status_IDX                              = 65,
-    SBK_QSoundEffect_IDX                                     = 63,
-    SBK_QVideoFrame_HandleType_IDX                           = 67,
-    SBK_QVideoFrame_MapMode_IDX                              = 68,
-    SBK_QVideoFrame_RotationAngle_IDX                        = 71,
-    SBK_QVideoFrame_IDX                                      = 66,
-    SBK_QVideoFrame_PaintOptions_PaintFlag_IDX               = 70,
+    SBK_QMediaRecorder_Quality_IDX                           = 58,
+    SBK_QMediaRecorder_EncodingMode_IDX                      = 56,
+    SBK_QMediaRecorder_RecorderState_IDX                     = 59,
+    SBK_QMediaRecorder_Error_IDX                             = 57,
+    SBK_QMediaRecorder_IDX                                   = 55,
+    SBK_QMediaTimeRange_IDX                                  = 60,
+    SBK_QMediaTimeRange_Interval_IDX                         = 61,
+    SBK_QPlaybackOptions_PlaybackIntent_IDX                  = 63,
+    SBK_QPlaybackOptions_IDX                                 = 62,
+    SBK_QScreenCapture_Error_IDX                             = 65,
+    SBK_QScreenCapture_IDX                                   = 64,
+    SBK_QSoundEffect_Loop_IDX                                = 67,
+    SBK_QSoundEffect_Status_IDX                              = 68,
+    SBK_QSoundEffect_IDX                                     = 66,
+    SBK_QVideoFrame_HandleType_IDX                           = 70,
+    SBK_QVideoFrame_MapMode_IDX                              = 71,
+    SBK_QVideoFrame_RotationAngle_IDX                        = 74,
+    SBK_QVideoFrame_IDX                                      = 69,
+    SBK_QVideoFrame_PaintOptions_PaintFlag_IDX               = 73,
     SBK_QFlags_QVideoFrame_PaintOptions_PaintFlag_IDX        = 34,
-    SBK_QVideoFrame_PaintOptions_IDX                         = 69,
-    SBK_QVideoFrameFormat_PixelFormat_IDX                    = 77,
-    SBK_QVideoFrameFormat_Direction_IDX                      = 76,
-    SBK_QVideoFrameFormat_YCbCrColorSpace_IDX                = 78,
-    SBK_QVideoFrameFormat_ColorSpace_IDX                     = 74,
-    SBK_QVideoFrameFormat_ColorTransfer_IDX                  = 75,
-    SBK_QVideoFrameFormat_ColorRange_IDX                     = 73,
-    SBK_QVideoFrameFormat_IDX                                = 72,
-    SBK_QVideoFrameInput_IDX                                 = 79,
-    SBK_QVideoSink_IDX                                       = 80,
-    SBK_QWaveDecoder_IDX                                     = 81,
-    SBK_QWindowCapture_Error_IDX                             = 83,
-    SBK_QWindowCapture_IDX                                   = 82,
-    SBK_QtVideo_Rotation_IDX                                 = 85,
-    SBK_QtMultimediaQtVideo_IDX                              = 84,
-    SBK_QtMultimedia_IDX_COUNT                               = 86,
+    SBK_QVideoFrame_PaintOptions_IDX                         = 72,
+    SBK_QVideoFrameFormat_PixelFormat_IDX                    = 80,
+    SBK_QVideoFrameFormat_Direction_IDX                      = 79,
+    SBK_QVideoFrameFormat_YCbCrColorSpace_IDX                = 81,
+    SBK_QVideoFrameFormat_ColorSpace_IDX                     = 77,
+    SBK_QVideoFrameFormat_ColorTransfer_IDX                  = 78,
+    SBK_QVideoFrameFormat_ColorRange_IDX                     = 76,
+    SBK_QVideoFrameFormat_IDX                                = 75,
+    SBK_QVideoFrameInput_IDX                                 = 82,
+    SBK_QVideoSink_IDX                                       = 83,
+    SBK_QWaveDecoder_IDX                                     = 84,
+    SBK_QWindowCapture_Error_IDX                             = 86,
+    SBK_QWindowCapture_IDX                                   = 85,
+    SBK_QtVideo_Rotation_IDX                                 = 88,
+    SBK_QtMultimediaQtVideo_IDX                              = 87,
+    SBK_QtMultimedia_IDX_COUNT                               = 89,
 };
 
 // This variable stores all Python types exported by this module.
@@ -352,6 +359,7 @@ template<> inline PyTypeObject *SbkType< ::QMediaPlayer::PlaybackState >() { ret
 template<> inline PyTypeObject *SbkType< ::QMediaPlayer::MediaStatus >() { return Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QMediaPlayer_MediaStatus_IDX]); }
 template<> inline PyTypeObject *SbkType< ::QMediaPlayer::Error >() { return Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QMediaPlayer_Error_IDX]); }
 template<> inline PyTypeObject *SbkType< ::QMediaPlayer::Loops >() { return Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QMediaPlayer_Loops_IDX]); }
+template<> inline PyTypeObject *SbkType< ::QMediaPlayer::PitchCompensationAvailability >() { return Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QMediaPlayer_PitchCompensationAvailability_IDX]); }
 template<> inline PyTypeObject *SbkType< ::QMediaPlayer >() { return Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QMediaPlayer_IDX]); }
 template<> inline PyTypeObject *SbkType< ::QMediaRecorder::Quality >() { return Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QMediaRecorder_Quality_IDX]); }
 template<> inline PyTypeObject *SbkType< ::QMediaRecorder::EncodingMode >() { return Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QMediaRecorder_EncodingMode_IDX]); }
@@ -360,6 +368,8 @@ template<> inline PyTypeObject *SbkType< ::QMediaRecorder::Error >() { return Sh
 template<> inline PyTypeObject *SbkType< ::QMediaRecorder >() { return Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QMediaRecorder_IDX]); }
 template<> inline PyTypeObject *SbkType< ::QMediaTimeRange >() { return Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QMediaTimeRange_IDX]); }
 template<> inline PyTypeObject *SbkType< ::QMediaTimeRange::Interval >() { return Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QMediaTimeRange_Interval_IDX]); }
+template<> inline PyTypeObject *SbkType< ::QPlaybackOptions::PlaybackIntent >() { return Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QPlaybackOptions_PlaybackIntent_IDX]); }
+template<> inline PyTypeObject *SbkType< ::QPlaybackOptions >() { return Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QPlaybackOptions_IDX]); }
 template<> inline PyTypeObject *SbkType< ::QScreenCapture::Error >() { return Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QScreenCapture_Error_IDX]); }
 template<> inline PyTypeObject *SbkType< ::QScreenCapture >() { return Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QScreenCapture_IDX]); }
 template<> inline PyTypeObject *SbkType< ::QSoundEffect::Loop >() { return Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QSoundEffect_Loop_IDX]); }
